@@ -15,11 +15,11 @@ our @EXPORT = qw(page_size fincore fadvise
             );
 our @EXPORT_OK = qw();
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 our $MAX_CHUNK_SIZE = 512*1024*1024;
 
-use POSIX;
+use POSIX qw(ceil);
 
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
